@@ -15,8 +15,12 @@ if len(missing_dependencies) > 0:
     )
 del hard_dependencies, dependency, missing_dependencies
 
-# import some ubclasses here so users can use for instance : 'enda.Contracts' without knowing the internal structure.
-# Do not import classes that need a specific package like
+# import some subclasses here so users can use for instance :
+# 'enda.Contracts' without knowing the internal structure.
+# Do not import classes that need a specific packages like "H2OModel".
 from enda.contracts import (Contracts)
 from enda.feature_engineering.datetime_features import (DatetimeFeature)
 from enda.timeseries import (TimeSeries)
+from enda.backtesting import (BackTesting)
+from enda.power_stations import (PowerStations)
+from enda.power_predictor import (PowerPredictor)
\ No newline at end of file
